@@ -35,7 +35,7 @@ use version 0.77;
 
 # PODNAME: Pod::Weaver::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.3.3'; # VERSION
+our $VERSION = 'v0.3.4'; # VERSION
 
 use Pod::Weaver::Config::Assembler;
 
@@ -110,6 +110,8 @@ sub mvp_bundle_config {
         [ 'OBJECT ATTRIBUTES',      $collect,   { command => 'attr'              } ],
         [ 'OBJECT METHODS',         $collect,   { command => 'method'            } ],
         [ 'FUNCTIONS',              $collect,   { command => 'func'              } ],
+        [ 'OPERATORS',              $collect,   { command => 'operator'          } ],
+        [ 'VARIABLES',              $collect,   { command => 'variable'          } ],
         [ 'OPTIONS',                $collect,   { command => 'option'            } ],
         [ 'RETURN VALUE',           $generic,   {} ],
         [ 'ERRORS',                 $generic,   {} ],
@@ -200,7 +202,7 @@ Pod::Weaver::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.3.3, released on 2016-12-15 23:11 UTC.
+Version v0.3.4, released on 2016-12-19 22:30 UTC.
 
 =head1 WHAT?
 
